# Generated by roxygen2: do not edit by hand

S3method(print,describe_studies)
export(cd)
export(describe_studies)
export(metamean)
export(metamedian)
export(metamedian_survival)
export(pool.med)
export(qe)
export(qe.study.level)
